import Image from "next/image";
import React, { useState } from "react";
import {
  CloseDisclosure,
  Edit,
  OpenDisclosure,
  PrimaryLogout,
  Trash,
} from "@/components/Icons";
import { Disclosure } from "@headlessui/react";
import FormCheck from "@/components/CheckBoxComponent/FormCheck";

export const EvaluatorProfileTab = ({ activeTab }) => {
  const [selectedTabIdx, setSelectedTabIdx] = useState(activeTab);
  const [file, setFile] = useState(null);
  const [preview, setPreview] = useState(null);

  const handleFileChange = (e) => {
    const selectedFile = e.target.files[0];
    setFile(selectedFile);
    setPreview(URL.createObjectURL(selectedFile));
  };
  const handleRemoveFile = () => {
    setFile(null);
    setPreview(null);
  };
  const tabs = [
    { name: "Overview", current: true },
    { name: "Edit Profile", current: false },
    { name: "Security", current: false },
    { name: "Change Password", current: false },
  ];
  const overview = [
    { key: "Full Name", value: "Fahad Ahmad" },
    { key: "Phone", value: "+92 3449020468" },
    { key: "Email", value: "Fahadahmadbs@gmail.com" },
    { key: "Role", value: "Asset Holder" },
    { key: "Gender", value: "Male" },
    { key: "Date of birth", value: "18 August 1999" },
    { key: "Nationality", value: "Pakistan" },
    { key: "Religion", value: "Islam" },
    { key: "Address", value: "Malakand, KPK, Pakistan" },
  ];
  return (
    <>
      {/* <span className='text-lg text-prussianBlue/40 mb-4 block'>My Profile 
            </span> */}
      <div className="custom-shadow rounded">
        <div className="primary-gradient border border-black rounded px-12 overflow-x-auto">
          <nav className="flex justify-between gap-3 w-full" aria-label="Tabs">
            {tabs.map((tab, i) => (
              <a
                key={tab.name}
                className={`
                             ${
                               i === selectedTabIdx
                                 ? "text-white border-b-4 border-white focus:outline-none "
                                 : ""
                             }
                                    whitespace-nowrap py-4 cursor-pointer text-xl`}
                onClick={() => setSelectedTabIdx(i)}
              >
                {tab.name}
              </a>
            ))}
          </nav>
        </div>
        {selectedTabIdx === 0 && (
          <div className="p-12">
            <h3 className="mb-3 text-prussianBlue text-2xl font-medium">
              About / Asset Holder
            </h3>
            <p className="text-lg mb-12">
              {
                "Lorem ipsum is derived from the Latin “dolorem ipsum” roughly translated as “pain itself.” Lorem ipsum presents the sample font and orientation of writing on web pages and other software applications where content is not the main concern of the developer."
              }
            </p>
            <h4 className="text-prussianBlue mb-7 text-2xl font-medium">
              Profile Details
            </h4>
            <div className="flex flex-col gap-4 text-xl">
              {overview.map((ele, i) => (
                <div key={i} className="flex">
                  <h4 className="w-[30%] font-medium">{ele.key}</h4>{" "}
                  <span className="text-black/60">{ele.value}</span>
                </div>
              ))}
            </div>
          </div>
        )}
        {selectedTabIdx === 1 && (
          <div className="p-12">
            <div className="flex gap-10 mb-16">
              <h2 className="text-prussianBlue text-xl font-medium">
                Profile Image{" "}
              </h2>
              <figure className="rounded-full relative shrink-0">
                <Image
                  className="rounded-full object-cover h-[170px] w-[170px]"
                  src={`${
                    preview ? preview : "/assets/images/seller-profile.png"
                  }`}
                  height={177}
                  width={177}
                  alt="profile"
                />
                <div className="absolute flex py-4 bg-white/60 gap-6 justify-center w-full bottom-0">
                  <label className="cursor-pointer" htmlFor="image-lpload">
                    <input
                      type="file"
                      onChange={handleFileChange}
                      className="hidden"
                      id="image-lpload"
                    />
                    <PrimaryLogout className="h-[24px] w-[24px] -rotate-90" />
                  </label>
                  <button onClick={handleRemoveFile}>
                    <Trash />
                  </button>
                </div>
              </figure>
            </div>
            <div className="flex flex-col gap-5 mb-7">
              <div className="flex">
                <h3 className="w-[30%]">Full Name</h3>
                <input
                  type="text"
                  className={`shadow-neons rounded w-full h-[48px] px-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input `}
                  placeholder="Fahad Ahmad"
                  name="Fahad Ahmad"
                />
              </div>
              <div className="flex ">
                <h3 className="w-[30%]">About</h3>
                <textarea
                  type="text"
                  rows={4}
                  className={`shadow-neons rounded w-full py-3 px-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input `}
                  placeholder="Fahad Ahmad"
                  name="Fahad Ahmad"
                />
              </div>
              <div className="flex">
                <h3 className="w-[30%]">Role</h3>
                <input
                  type="text"
                  className={`shadow-neons rounded w-full h-[48px] px-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input `}
                  placeholder="Asset Holder"
                  name="Asset Holder"
                />
              </div>
              <div className="flex">
                <h3 className="w-[30%]">Country</h3>
                <input
                  type="text"
                  className={`shadow-neons rounded w-full h-[48px] px-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input `}
                  placeholder="Pakistan"
                  name="Pakistan"
                />
              </div>
              <div className="flex">
                <h3 className="w-[30%]">Address</h3>
                <input
                  type="text"
                  className={`shadow-neons rounded w-full h-[48px] px-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input `}
                  placeholder="Malakand, KPK, Pakistan"
                  name="Malakand, KPK, Pakistan"
                />
              </div>
              <div className="flex">
                <h3 className="w-[30%]">Phone</h3>
                <input
                  type="text"
                  className={`shadow-neons rounded w-full h-[48px] px-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input `}
                  placeholder="+92 344 9020468"
                  name="+92 344 9020468"
                />
              </div>
              <div className="flex">
                <h3 className="w-[30%]">Email</h3>
                <input
                  type="email"
                  className={`shadow-neons rounded w-full h-[48px] px-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input `}
                  placeholder="Fahadahmadbs@gmail.com"
                  name="Fahadahmadbs@gmail.com"
                />
              </div>
              <div className="flex">
                <h3 className="w-[30%]">Gender</h3>
                <div className="flex gap-10 text-black/50">
                  <label className="cursor-pointer" htmlFor="Male">
                    <input type="radio" name="same" id="Male" /> Male
                  </label>
                  <label className="cursor-pointer" htmlFor="Female">
                    <input type="radio" name="same" id="Female" /> Female
                  </label>
                  <label className="cursor-pointer" htmlFor="Other">
                    <input type="radio" name="same" id="Other" /> Other
                  </label>
                </div>
              </div>
              <div className="flex">
                <h3 className="w-[30%]">Religion</h3>
                <input
                  type="text"
                  className={`shadow-neons rounded w-full h-[48px] px-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input `}
                  placeholder="Islam"
                  name="Islam"
                />
              </div>
              <div className="flex">
                <h3 className="w-[30%]">Dat Of Birth</h3>
                <input
                  type="text"
                  className={`shadow-neons rounded w-full h-[48px] px-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input `}
                  placeholder="18 August 1999"
                  name="18 August 1999"
                />
              </div>
              <div className="flex relative">
                <h3 className="w-[30%]">Twitter Profile</h3>
                <input
                  type="text"
                  className={`shadow-neons rounded w-full h-[48px] px-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input `}
                  placeholder="https://www.twitter/fahadahmad/"
                  name="https://www.twitter/fahadahmad/"
                />
                <button className="absolute right-3 top-4">
                  <Edit />
                </button>
              </div>
              <div className="flex relative">
                <h3 className="w-[30%]">Facebook Profile</h3>
                <input
                  type="text"
                  className={`shadow-neons rounded w-full h-[48px] px-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input `}
                  placeholder="https://www.facebook/fahadahmad/"
                  name="https://www.facebook/fahadahmad/"
                />
                <button className="absolute right-3 top-4">
                  <Edit />
                </button>
              </div>
              <div className="flex relative">
                <h3 className="w-[30%]">Instagram Profile</h3>
                <input
                  type="text"
                  className={`shadow-neons rounded w-full h-[48px] px-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input `}
                  placeholder="https://www.Instagram/fahadahmad/"
                  name="https://www.Instagram/fahadahmad/"
                />
                <button className="absolute right-3 top-4">
                  <Edit />
                </button>
              </div>
              <div className="flex relative">
                <h3 className="w-[30%]">Linkedin Profile</h3>
                <input
                  type="text"
                  className={`shadow-neons rounded w-full h-[48px] px-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input `}
                  placeholder="https://www.Linkedin/fahadahmad/"
                  name="https://www.Linkedin/fahadahmad/"
                />
                <button className="absolute right-3 top-4">
                  <Edit />
                </button>
              </div>
              <div className="flex relative">
                <h3 className="w-[30%]">Twitter Profile</h3>
                <input
                  type="text"
                  className={`shadow-neons rounded w-full h-[48px] px-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input `}
                  placeholder="https://www.Twitter/fahadahmad/"
                  name="https://www.Twitter/fahadahmad/"
                />
                <button className="absolute right-3 top-4">
                  <Edit />
                </button>
              </div>
              <div className="flex relative">
                <h3 className="w-[30%]">Tiktok Profile</h3>
                <input
                  type="text"
                  className={`shadow-neons rounded w-full h-[48px] px-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input `}
                  placeholder="https://www.Tiktok/fahadahmad/"
                  name="https://www.Tiktok/fahadahmad/"
                />
                <button className="absolute right-3 top-4">
                  <Edit />
                </button>
              </div>
            </div>
            <button className="px-6 py-3 mx-auto block rounded primary-gradient text-white">
              Save Changes
            </button>
          </div>
        )}
        {selectedTabIdx === 2 && (
          <div className="p-12">
            <Disclosure as="div" className={`mb-4`} defaultOpen={true}>
              {({ open }) => (
                <>
                  <Disclosure.Button
                    className={`w-full custom-shadow rounded py-3 px-7 gap-4 flex-wrap justify-between items-center flex ${
                      open && "mb-3"
                    }`}
                  >
                    <span className="whitespace-nowrap">
                      2-Step Verification
                    </span>
                    <span className="whitespace-nowrap">
                      On since 22 April 2024
                    </span>
                    <span className="flex-shrink-0">
                      {open ? (
                        <OpenDisclosure className="text-prussianBlue" />
                      ) : (
                        <CloseDisclosure className="text-prussianBlue" />
                      )}
                    </span>
                  </Disclosure.Button>
                  <Disclosure.Panel as="div" className="px-7 py-4">
                    <p className="mb-2">
                      {"Your account is protected with 2-Step Verification"}
                    </p>
                    <p className="mb-4 text-black/60">
                      {
                        "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat."
                      }
                    </p>
                    <button className="py-2 px-8 primary-gradient rounded">
                      Turn Off 2-Step Verification{" "}
                    </button>
                  </Disclosure.Panel>
                </>
              )}
            </Disclosure>
            <Disclosure as="div" className={`mb-4`} defaultOpen={true}>
              {({ open }) => (
                <>
                  <Disclosure.Button
                    className={`w-full custom-shadow rounded py-3 px-7 gap-4 justify-between items-center flex ${
                      open && "mb-3"
                    }`}
                  >
                    <span className="whitespace-nowrap">
                      Email Verification
                    </span>
                    <span className="flex-shrink-0">
                      {open ? (
                        <OpenDisclosure className="text-prussianBlue" />
                      ) : (
                        <CloseDisclosure className="text-prussianBlue" />
                      )}
                    </span>
                  </Disclosure.Button>
                  <Disclosure.Panel
                    as="div"
                    className="px-7 py-4 flex  flex-col items-start gap-4"
                  >
                    <p>Verify Your Email </p>
                    <input
                      type="email"
                      className={`shadow-neons rounded w-full sm:w-[50%] h-[48px] px-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input `}
                      placeholder="smbdigitalzone@gmail.com"
                      name="smbdigitalzone@gmail.com"
                    />
                    <button className="py-2 px-4 primary-gradient rounded">
                      Verify
                    </button>
                  </Disclosure.Panel>
                </>
              )}
            </Disclosure>
            <Disclosure as="div" className={`mb-4`} defaultOpen={true}>
              {({ open }) => (
                <>
                  <Disclosure.Button
                    className={`w-full custom-shadow rounded flex-wrap py-3 px-7 gap-4 justify-between items-center flex ${
                      open && "mb-3"
                    }`}
                  >
                    <span className="whitespace-nowrap">Recovery email</span>
                    <span className="whitespace-nowrap">Add Email Address</span>
                    <span className="flex-shrink-0">
                      {open ? (
                        <OpenDisclosure className="text-prussianBlue" />
                      ) : (
                        <CloseDisclosure className="text-prussianBlue" />
                      )}
                    </span>
                  </Disclosure.Button>
                  <Disclosure.Panel
                    as="div"
                    className="px-7 py-4 flex  flex-col items-start gap-4"
                  >
                    <p>Add Your Recovery email</p>
                    <input
                      type="email"
                      className={`shadow-neons rounded w-full sm:w-[50%] h-[48px] px-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input `}
                      placeholder="smbdigitalzone@gmail.com"
                      name="smbdigitalzone@gmail.com"
                    />
                    <div className="flex gap-8">
                      <button className="py-2 px-4 primary-gradient rounded">
                        Next
                      </button>
                      <button className="text-prussianBlue">Cancel</button>
                    </div>
                  </Disclosure.Panel>
                </>
              )}
            </Disclosure>
          </div>
        )}
        {selectedTabIdx === 3 && (
          <div className="p-12">
            <Disclosure as="div" className={`mb-4`} defaultOpen={true}>
              {({ open }) => (
                <>
                  <Disclosure.Button
                    className={`w-full custom-shadow rounded py-3 px-7 gap-4 flex-wrap justify-between items-center flex ${
                      open && "mb-3"
                    }`}
                  >
                    <span className="whitespace-nowrap">Password</span>
                    <span className="whitespace-nowrap">
                      Last changed 22 April 2024
                    </span>
                    <span className="flex-shrink-0">
                      {open ? (
                        <OpenDisclosure className="text-prussianBlue" />
                      ) : (
                        <CloseDisclosure className="text-prussianBlue" />
                      )}
                    </span>
                  </Disclosure.Button>
                  <Disclosure.Panel
                    as="div"
                    className="grid gap-4 sm:gap-12 sm:grid-cols-2 px-7 py-4"
                  >
                    <div>
                      <p className="mb-5">Choose a strong password</p>
                      <input
                        type="password"
                        className={`mb-4 shadow-neons rounded w-full h-[48px] px-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input `}
                        placeholder="Old Password*"
                        name="Old Password*"
                      />
                      <input
                        type="password"
                        className={`mb-4 shadow-neons rounded w-full h-[48px] px-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input `}
                        placeholder="New Password*"
                        name="New Password*"
                      />
                      <input
                        type="password"
                        className={`mb-4 shadow-neons rounded w-full h-[48px] px-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input `}
                        placeholder="Re-Type New Password*"
                        name="Re-Type New Password*"
                      />
                      <div className="flex gap-4">
                        <button className="py-2 px-4 primary-gradient rounded ">
                          Changed Password
                        </button>
                        <button className="  text-prussianBlue rounded">
                          Cancel
                        </button>
                      </div>
                    </div>
                    <div className="flex flex-col gap-2">
                      <p className="mb-7">Password Requirements</p>
                      <FormCheck label="Minimum 8 Characters" id="1" />
                      <FormCheck label="UPPERCASE letter" id="2" />
                      <FormCheck label="lowercase letter" id="3" />
                      <FormCheck label="Numbers" id="4" />
                      <FormCheck label="Special Symbols" id="5" />
                    </div>
                  </Disclosure.Panel>
                </>
              )}
            </Disclosure>
          </div>
        )}
      </div>
    </>
  );
};
